@@ -14,7 +14,7 @@ use File::Glob qw(:bsd_glob);
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 use Data::Dump qw(dump);
 
-our $VERSION = '2017.114';
+our $VERSION = '2017.116';
 
 &saveToS3('DataTableText') if 0;                                                # Save code
 
@@ -455,12 +455,7 @@ sub extractDocumentation()
         if $p and $c and $c !~ /\A#/;                                           # Add parameter description if present
      }
    }
-  push @d, <<END;                                                               # Index
-
-=head1 Index
-
-The following methods will be exported by the :all tag:
-END
+  push @d, "=head1 Index\n\n";
   push @d, "L</$_>" for sort keys %methodParms;                                 # Alphabetic listing of methods
   push @d, "\n";
   writeFile("doc.data",     join "\n", @d);                                     # Write documentation file
